==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/VulnerabilityAssessmentRecurringScansPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.VulnerabilityAssessmentRecurringScansPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties of a Vulnerability Assessment recurring scans.
 * @property emailSubscriptionAdmins Specifies that the schedule scan notification will be is sent to the subscription administrators.
 * @property emails Specifies an array of e-mail addresses to which the scan notification is sent.
 * @property isEnabled Recurring scans state.
 */
public data class VulnerabilityAssessmentRecurringScansPropertiesArgs(
    public val emailSubscriptionAdmins: Output<Boolean>? = null,
    public val emails: Output<List<String>>? = null,
    public val isEnabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.VulnerabilityAssessmentRecurringScansPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.synapse.inputs.VulnerabilityAssessmentRecurringScansPropertiesArgs =
        com.pulumi.azurenative.synapse.inputs.VulnerabilityAssessmentRecurringScansPropertiesArgs.builder()
            .emailSubscriptionAdmins(emailSubscriptionAdmins?.applyValue({ args0 -> args0 }))
            .emails(emails?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .isEnabled(isEnabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VulnerabilityAssessmentRecurringScansPropertiesArgs].
 */
@PulumiTagMarker
public class VulnerabilityAssessmentRecurringScansPropertiesArgsBuilder internal constructor() {
    private var emailSubscriptionAdmins: Output<Boolean>? = null

    private var emails: Output<List<String>>? = null

    private var isEnabled: Output<Boolean>? = null

    /**
     * @param value Specifies that the schedule scan notification will be is sent to the subscription administrators.
     */
    @JvmName("xbrywsdtsbrmslve")
    public suspend fun emailSubscriptionAdmins(`value`: Output<Boolean>) {
        this.emailSubscriptionAdmins = value
    }

    /**
     * @param value Specifies an array of e-mail addresses to which the scan notification is sent.
     */
    @JvmName("edhydpgmjkpndeao")
    public suspend fun emails(`value`: Output<List<String>>) {
        this.emails = value
    }

    @JvmName("nycghmapahajollb")
    public suspend fun emails(vararg values: Output<String>) {
        this.emails = Output.all(values.asList())
    }

    /**
     * @param values Specifies an array of e-mail addresses to which the scan notification is sent.
     */
    @JvmName("ycmbfdjpxnumiulo")
    public suspend fun emails(values: List<Output<String>>) {
        this.emails = Output.all(values)
    }

    /**
     * @param value Recurring scans state.
     */
    @JvmName("wcvvoppjktontqbj")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value Specifies that the schedule scan notification will be is sent to the subscription administrators.
     */
    @JvmName("jfgysscbdqaporik")
    public suspend fun emailSubscriptionAdmins(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.emailSubscriptionAdmins = mapped
    }

    /**
     * @param value Specifies an array of e-mail addresses to which the scan notification is sent.
     */
    @JvmName("qyjlqcphglfwdtyr")
    public suspend fun emails(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.emails = mapped
    }

    /**
     * @param values Specifies an array of e-mail addresses to which the scan notification is sent.
     */
    @JvmName("oprxnsjnmccaxkbr")
    public suspend fun emails(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.emails = mapped
    }

    /**
     * @param value Recurring scans state.
     */
    @JvmName("hnovvbxobcvylrro")
    public suspend fun isEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    internal fun build(): VulnerabilityAssessmentRecurringScansPropertiesArgs =
        VulnerabilityAssessmentRecurringScansPropertiesArgs(
            emailSubscriptionAdmins = emailSubscriptionAdmins,
            emails = emails,
            isEnabled = isEnabled,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/VulnerabilityAssessmentRecurringScansPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.VulnerabilityAssessmentRecurringScansPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties of a Vulnerability Assessment recurring scans.
 * @property emailSubscriptionAdmins Specifies that the schedule scan notification will be is sent to the subscription administrators.
 * @property emails Specifies an array of e-mail addresses to which the scan notification is sent.
 * @property isEnabled Recurring scans state.
 */
public data class VulnerabilityAssessmentRecurringScansPropertiesArgs(
    public val emailSubscriptionAdmins: Output<Boolean>? = null,
    public val emails: Output<List<String>>? = null,
    public val isEnabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.VulnerabilityAssessmentRecurringScansPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.synapse.inputs.VulnerabilityAssessmentRecurringScansPropertiesArgs =
        com.pulumi.azurenative.synapse.inputs.VulnerabilityAssessmentRecurringScansPropertiesArgs.builder()
            .emailSubscriptionAdmins(emailSubscriptionAdmins?.applyValue({ args0 -> args0 }))
            .emails(emails?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .isEnabled(isEnabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VulnerabilityAssessmentRecurringScansPropertiesArgs].
 */
@PulumiTagMarker
public class VulnerabilityAssessmentRecurringScansPropertiesArgsBuilder internal constructor() {
    private var emailSubscriptionAdmins: Output<Boolean>? = null

    private var emails: Output<List<String>>? = null

    private var isEnabled: Output<Boolean>? = null

    /**
     * @param value Specifies that the schedule scan notification will be is sent to the subscription administrators.
     */
    @JvmName("cjuejpqdylomvloe")
    public suspend fun emailSubscriptionAdmins(`value`: Output<Boolean>) {
        this.emailSubscriptionAdmins = value
    }

    /**
     * @param value Specifies an array of e-mail addresses to which the scan notification is sent.
     */
    @JvmName("qjkrcdxargnkutyp")
    public suspend fun emails(`value`: Output<List<String>>) {
        this.emails = value
    }

    @JvmName("sfcldogivrigatqp")
    public suspend fun emails(vararg values: Output<String>) {
        this.emails = Output.all(values.asList())
    }

    /**
     * @param values Specifies an array of e-mail addresses to which the scan notification is sent.
     */
    @JvmName("xsfvxulgygeiavvm")
    public suspend fun emails(values: List<Output<String>>) {
        this.emails = Output.all(values)
    }

    /**
     * @param value Recurring scans state.
     */
    @JvmName("pojfsanjyeitdgdv")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value Specifies that the schedule scan notification will be is sent to the subscription administrators.
     */
    @JvmName("pbckdtrgydnibkkb")
    public suspend fun emailSubscriptionAdmins(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.emailSubscriptionAdmins = mapped
    }

    /**
     * @param value Specifies an array of e-mail addresses to which the scan notification is sent.
     */
    @JvmName("ikblbitokfwrkqpo")
    public suspend fun emails(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.emails = mapped
    }

    /**
     * @param values Specifies an array of e-mail addresses to which the scan notification is sent.
     */
    @JvmName("imycmpgomvocuiox")
    public suspend fun emails(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.emails = mapped
    }

    /**
     * @param value Recurring scans state.
     */
    @JvmName("clwunnkebgmyasgw")
    public suspend fun isEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    internal fun build(): VulnerabilityAssessmentRecurringScansPropertiesArgs =
        VulnerabilityAssessmentRecurringScansPropertiesArgs(
            emailSubscriptionAdmins = emailSubscriptionAdmins,
            emails = emails,
            isEnabled = isEnabled,
        )
}
